@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HTML-TEMPLATE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/html-template/specials.lisp,v 1.15 2005/07/03 11:13:52 edi Exp $
+;;; $Header: /usr/local/cvsrep/html-template/specials.lisp,v 1.17 2006/01/03 18:41:44 edi Exp $
 
-;;; Copyright (c) 2003, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2003-2006, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -93,6 +93,10 @@ TMPL_INCLUDE loops.")
   "The function which associates \(attribute) symbols with their
 values.")
 
+(defvar *force-default* nil
+  "The default value for the FORCE keyword argument to
+CREATE-TEMPLATE-PRINTER.")
+
 ;; stuff for Nikodemus Siivola's HYPERDOC
 ;; see <http://common-lisp.net/project/hyperdoc/>
 ;; and <http://www.cliki.net/hyperdoc>
