@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HTML-TEMPLATE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/html-template/template.lisp,v 1.17 2005/07/03 11:13:52 edi Exp $
+;;; $Header: /usr/local/cvsrep/html-template/template.lisp,v 1.19 2006/04/03 08:35:53 edi Exp $
 
-;;; Copyright (c) 2003, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2003-2006, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -92,14 +92,16 @@ printed first."
           (funcall (car (gethash symbol/pathname *printer-hash*)) values)
           (funcall next-fn values))))))
   
-(defun create-if-printer (string-list symbol if-fn else-fn next-fn)
-  "Used internally to create template printers for TMPL_IF
-tags. SYMBOL is the symbol associated with the tag. IF-FN is the
-printer for the IF branch, ELSE-FN is the printer for the ELSE
-branch. NEXT-FN is the next function to be called in the chain of
-closures. STRING-LIST is a list of strings in reverse order to be
-printed first."
+(defun create-if-printer (string-list symbol if-fn else-fn next-fn unlessp)
+  "Used internally to create template printers for TMPL_IF and
+TMPL_UNLESS tags. SYMBOL is the symbol associated with the tag.  IF-FN
+is the printer for the IF branch, ELSE-FN is the printer for the ELSE
+branch.  NEXT-FN is the next function to be called in the chain of
+closures.  STRING-LIST is a list of strings in reverse order to be
+printed first.  If UNLESSP is true, IF-FN and ELSE-FN are switched."
   (let ((string (list-to-string string-list)))
+    (when unlessp
+      (rotatef if-fn else-fn))
     (lambda (values)
       (write-string string *template-output*)
       (if (funcall *value-access-function* symbol values)
@@ -131,13 +133,14 @@ of strings in reverse order to be printed first."
 
 (defun create-template-printer-aux (string-stack end-token)
   "Reads from *STANDARD-INPUT* and returns a template printer from
-what it reads. When this function is entered the stream pointer must
-not be inside a template tag. STRING-STACK is a list of strings (in
+what it reads.  When this function is entered the stream pointer must
+not be inside a template tag.  STRING-STACK is a list of strings (in
 reverse order) read so far which haven't been used to build a template
-printer. END-TOKEN is either NIL or one of :LOOP, :IF, or :ELSE
-denoting that we expect certain tags to close open TMPL_LOOP and/or
-TMPL_IF tags. This function returns a second value which is true if,
-after reading TMPL_IF, a corresponding TMPL_ELSE was seen."
+printer.  END-TOKEN is either NIL or one of :LOOP, :IF, :IF-ELSE, or
+:UNLESS-ELSE denoting that we expect certain tags to close open
+TMPL_LOOP, TMPL_IF, or TMPL_UNLESS tags.  This function returns a
+second value which is true if, after reading TMPL_IF or TMPL_UNLESS, a
+corresponding TMPL_ELSE was seen."
   (let* ((string
            ;; read text up to the next template start marker
            (read-until *template-start-marker*
@@ -152,7 +155,8 @@ after reading TMPL_IF, a corresponding TMPL_ELSE was seen."
                                         "Unexpected EOF, ~A tag is missing"
                                         (case end-token
                                           ((:loop) "<!-- /TMPL_LOOP -->")
-                                          ((:if :else) "<!-- /TMPL_IF -->"))))
+                                          ((:if :if-else) "<!-- /TMPL_IF -->")
+                                          ((:unless :unless-else) "<!-- /TMPL_UNLESS -->"))))
                                      ;; otherwise (EOF before another
                                      ;; start marker was seen) just
                                      ;; return a template printer
@@ -269,34 +273,36 @@ after reading TMPL_IF, a corresponding TMPL_ELSE was seen."
             ;; this is the end of some TMPL_LOOP body
             (create-simple-printer (cons (skip-leading-whitespace string)
                                          string-stack)))
-          ((string-equal token "TMPL_IF")
-            ;; TMPL_IF tag - first read the symbol which has to follow
-            ;; and intern it
-            (let ((symbol (read-tag-rest :read-attribute t)))
+          ((or (string-equal token "TMPL_IF")
+               (string-equal token "TMPL_UNLESS"))
+            ;; TMPL_IF or TMPL_UNLESS tag - first read the symbol
+            ;; which has to follow and intern it
+            (let ((symbol (read-tag-rest :read-attribute t))
+                  (unlessp (string-equal token "TMPL_UNLESS")))
               (multiple-value-bind (if-fn else-follows)
                   (with-syntax-error-location ()
                     ;; then read the stream up to the corresponding
-                    ;; TMPL_ELSE or /TMPL_IF and create a template
-                    ;; printer for the "if" part
+                    ;; TMPL_ELSE, /TMPL_IF, or /TMPL_UNLESS and create
+                    ;; a template printer for the "if" (or "unless") part
                     (create-template-printer-aux
                      (skip-trailing-whitespace)
                      ;; this argument denotes that we expect to see
-                     ;; TMPL_ELSE _or_ /TMPL_IF and, in the second
-                     ;; case, want to stop there
-                     :else))
+                     ;; TMPL_ELSE _or_ one of /TMPL_IF, /TMPL_UNLESS and,
+                     ;; in the second case, want to stop there
+                     (if unlessp :unless-else :if-else)))
                 (let ((else-fn (if else-follows
                                  ;; if we encountered TMPL_ELSE read
                                  ;; the stream up to the corresponding
-                                 ;; /TMPL_IF and create a template
-                                 ;; printer for the "else" part
+                                 ;; /TMPL_IF or /TMPL_UNLESS and
+                                 ;; create a template printer for the "else" part
                                  (with-syntax-error-location ()
                                    (create-template-printer-aux
                                     (skip-trailing-whitespace)
                                     ;; this argument denotes that we
-                                    ;; expect to see /TMPL_IF (but not
-                                    ;; TMPL_ELSE) and want to stop
+                                    ;; expect to see /TMPL_IF or /TMPL_UNLESS
+                                    ;; (but not TMPL_ELSE) and want to stop
                                     ;; there
-                                    :if))
+                                    (if unlessp :unless :if)))
                                  ;; use a dummy printer for the "else"
                                  ;; part if we didn't see TMPL_ELSE
                                  #'no-values)))
@@ -308,19 +314,20 @@ after reading TMPL_IF, a corresponding TMPL_ELSE was seen."
                     (values
                      ;; then we combine it with the strings before the
                      ;; tag and the "if" and "else" parts to create a
-                     ;; template printer for TMPL_IF
+                     ;; template printer for TMPL_IF or TMPL_UNLESS
                      (create-if-printer (cons (skip-leading-whitespace string)
                                               string-stack)
                                         symbol
                                         if-fn
                                         else-fn
-                                        next-fn)
+                                        next-fn
+                                        unlessp)
                      else-follows))))))
           ((string-equal token "TMPL_ELSE")
-            (unless (eq end-token :else)
+            (unless (member end-token '(:if-else :unless-else))
               ;; check if we expected /TMPL_ELSE here, i.e. if an open
-              ;; TMPL_IF was pending and we haven't seen TMPL_ELSE
-              ;; before
+              ;; TMPL_IF or TMPL_UNLESS was pending and we haven't
+              ;; seen TMPL_ELSE before
               (with-syntax-error-location ()
                 (signal-template-syntax-error "Unexpected TMPL_ELSE")))
             ;; read the rest of the tag but ignore it - no attributes
@@ -335,7 +342,7 @@ after reading TMPL_IF, a corresponding TMPL_ELSE was seen."
              ;; TMPL_ELSE
              t))
           ((string-equal token "/TMPL_IF")
-            (unless (or (eq end-token :if) (eq end-token :else))
+            (unless (or (eq end-token :if) (eq end-token :if-else))
               ;; check if we expected /TMPL_IF here, i.e. if an open
               ;; TMPL_IF was pending
               (with-syntax-error-location ()
@@ -347,6 +354,19 @@ after reading TMPL_IF, a corresponding TMPL_ELSE was seen."
             ;; this is the end of some "if" or "else" part
             (create-simple-printer (cons (skip-leading-whitespace string)
                                          string-stack)))
+          ((string-equal token "/TMPL_UNLESS")
+            (unless (or (eq end-token :unless) (eq end-token :unless-else))
+              ;; check if we expected /TMPL_UNLESS here, i.e. if an open
+              ;; TMPL_UNLESS was pending
+              (with-syntax-error-location ()
+                (signal-template-syntax-error "Unexpected /TMPL_UNLESS")))
+            ;; read the rest of the tag but ignore it - no attributes
+            ;; expected
+            (read-tag-rest)
+            ;; just create a simple template printer for strings -
+            ;; this is the end of some "unless" or "else" part
+            (create-simple-printer (cons (skip-leading-whitespace string)
+                                         string-stack)))
           (t
             ;; we couldn't identify a valid tag, so we treat
             ;; everything we've read so far as a literal string and
