@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HTML-TEMPLATE-TEST; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/html-template/test.lisp,v 1.7 2003/07/15 19:07:52 edi Exp $
+;;; $Header: /usr/local/cvsrep/html-template/test.lisp,v 1.9 2006/04/03 08:35:53 edi Exp $
 
-;;; Copyright (c) 2003, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2003-2006, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -78,8 +78,12 @@
 (test nil "<!-- TMPL_IF foo -->abc<!-- /TMPL_IF foo -->" nil)
 (test nil "<!-- TMPL_IF -->abc<!-- /TMPL_IF -->" nil)
 (test "def" "<!-- TMPL_IF foo -->abc<!-- TMPL_ELSE-->def<!-- /TMPL_IF -->" nil)
+(test nil "<!-- TMPL_IF foo -->abc<!-- TMPL_ELSE-->def<!-- /TMPL_UNLESS -->" nil)
 (test "def" "<!-- TMPL_IF foo -->abc<!-- TMPL_ELSE-->def<!-- /TMPL_IF -->" '(:foo nil))
 (test "abc" "<!-- TMPL_IF foo -->abc<!-- TMPL_ELSE-->def<!-- /TMPL_IF -->" '(:foo t))
+(test "abc" "<!-- TMPL_UNLESS foo -->abc<!-- TMPL_ELSE-->def<!-- /TMPL_UNLESS -->" '(:foo nil))
+(test "def" "<!-- TMPL_UNLESS foo -->abc<!-- TMPL_ELSE-->def<!-- /TMPL_UNLESS -->" '(:foo t))
+(test nil "<!-- TMPL_UNLESS foo -->abc<!-- TMPL_ELSE-->def<!-- /TMPL_IF -->" '(:foo t))
 (test "abc" "<!-- TMPL_IF foo --><!-- TMPL_VAR foo --><!-- TMPL_ELSE-->def<!-- /TMPL_IF -->" '(:foo "abc"))
 (test "def" "<!-- TMPL_IF foo --><!-- TMPL_VAR foo --><!-- TMPL_ELSE-->def<!-- /TMPL_IF -->" '(:foo nil))
 (test "abcabcabc" "<!-- TMPL_IF foo --><!-- TMPL_VAR foo -->abc<!-- TMPL_VAR foo --><!-- TMPL_ELSE-->def<!-- /TMPL_IF -->" '(:foo "abc"))
@@ -100,8 +104,10 @@
 (test nil "<!-- TMPL_ELSE -->" nil)
 (test "<!-- /TMPL_ELSE -->" "<!-- /TMPL_ELSE -->" nil)
 (test nil "<!-- /TMPL_IF -->" nil)
+(test nil "<!-- /TMPL_UNLESS -->" nil)
 (test nil "<!-- /TMPL_LOOP -->" nil)
 (test nil "<!-- TMPL_IF foo --><!-- TMPL_ELSE -->" nil)
+(test nil "<!-- TMPL_UNLESS foo --><!-- TMPL_ELSE -->" nil)
 (test nil "<!-- TMPL_LOOP foo --><!-- TMPL_ELSE -->" nil)
 (test nil "<!-- TMPL_LOOP foo --><!-- TMPL_ELSE --><!-- /TMPL_LOOP -->" nil)
 (test nil "<!-- TMPL_IF bar --><!-- TMPL_LOOP foo --><!-- TMPL_ELSE --><!-- /TMPL_LOOP -->" nil)
